@@ -58,13 +58,13 @@
         (is.logical(suppressUpdates) && 1L != length(suppressUpdates)))
         .stop("'suppressUpdates' must be character() or logical(1)")
 
-    biocMirror <- getOption("BioC_mirror", "http://bioconductor.org")
+    biocMirror <- getOption("BioC_mirror",
+                            sprintf("%s//bioconductor.org", .protocol()))
     .message("BioC_mirror: %s", biocMirror)
 
-    version <- getRversion()
-    thisRVer <- sprintf("%d.%d", version$major, version$minor)
-    .message("Using Bioconductor version %s (BiocInstaller %s), R version %s.",
-             biocVersion(), packageVersion("BiocInstaller"), version)
+    .message("Using Bioconductor %s (BiocInstaller %s), %s.",
+             biocVersion(), packageVersion("BiocInstaller"),
+             sub(" version", "", R.version.string))
 
     if (!suppressPackageStartupMessages(require("utils", quietly=TRUE)))
         .stop("failed to load package 'utils'")
